[![made-with-python](https://img.shields.io/badge/Made%20with-Python-1f425f.svg)](https://www.python.org/)
![PyPI - Downloads](https://img.shields.io/pypi/dw/tehran_stocks.svg?color=blue)
[![PyPI version](https://badge.fury.io/py/tehran-stocks.svg)](https://badge.fury.io/py/tehran-stocks)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/python/black)

<!-- ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/tehran-stocks.svg) -->

# Tehran Stock Market

A python package that helps to access TCCIM stock price hisotry

## Features

- Download and update Data
- Compatible with `sqlalchemy`
- Compatible with `PANDAS`
- `sqlite`

## Todo

- [x] Download Data
- [ ] CommandLine Support
- [ ] Jalali Support
